@@ -1,25 +1,20 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, print_function, unicode_literals
-
-from django.db import models
-from django.utils.translation import ugettext_lazy as _
-
 from app_data import AppDataField
-from six import python_2_unicode_compatible
+from django.db import models
+from django.utils.translation import gettext_lazy as _
 
 
-@python_2_unicode_compatible
 class AppHookConfig(models.Model):
     """
     This is the generic (abstract) model that holds the configurations for each AppHookConfig
     concrete model
     """
+
     type = models.CharField(
-        _('Type'),
+        _("Type"),
         max_length=100,
     )
     namespace = models.CharField(
-        _('Instance namespace'),
+        _("Instance namespace"),
         default=None,
         max_length=100,
         unique=True,
@@ -29,21 +24,20 @@ class AppHookConfig(models.Model):
     cmsapp = None
 
     class Meta:
-        verbose_name = _('Apphook config')
-        verbose_name_plural = _('Apphook configs')
-        unique_together = ('type', 'namespace')
+        verbose_name = _("Apphook config")
+        verbose_name_plural = _("Apphook configs")
+        unique_together = ("type", "namespace")
         abstract = True
 
     def save(self, *args, **kwargs):
-        self.type = '%s.%s' % (
-            self.__class__.__module__, self.__class__.__name__)
-        super(AppHookConfig, self).save(*args, **kwargs)
+        self.type = "{}.{}".format(self.__class__.__module__, self.__class__.__name__)
+        super().save(*args, **kwargs)
 
     def __str__(self):
         if self.cmsapp:
-            return '%s / %s' % (self.cmsapp.name, self.namespace)
+            return "{} / {}".format(self.cmsapp.name, self.namespace)
         else:
-            return '%s / %s' % (self.type, self.namespace)
+            return "{} / {}".format(self.type, self.namespace)
 
     def __getattr__(self, item):
         """
@@ -55,4 +49,4 @@ class AppHookConfig(models.Model):
         try:
             return getattr(self.app_data.config, item)
         except Exception:
-            raise AttributeError('attribute %s not found' % item)
+            raise AttributeError("attribute %s not found" % item)
